@@ -1,5 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
+# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -155,7 +156,7 @@ sub Run {
             $File = $CustomFile;
         }
 
-        for ( 1 .. $NumberOfTestRuns ) {
+        for my $Count ( 1 .. $NumberOfTestRuns ) {
             $Self->_HandleFile(
                 PostTestScripts => $Param{PostTestScripts},
                 File            => $File,
